@@ -21,6 +21,8 @@
 
 #include "mixer_pulse.h"
 
+#include "qtpamainloop.h"
+
 #include <cstdlib>
 #include <QAbstractEventDispatcher>
 #include <QTimer>
@@ -32,7 +34,6 @@
 #include "core/ControlManager.h"
 #include "core/GlobalConfig.h"
 
-#include <pulse/glib-mainloop.h>
 #include <pulse/ext-stream-restore.h>
 #if defined(HAVE_CANBERRA)
 #  include <canberra.h>
@@ -55,7 +56,6 @@
 #define KMIXPA_EVENT_KEY "sink-input-by-media-role:event"
 
 static unsigned int refcount = 0;
-static pa_glib_mainloop *s_mainloop = NULL;
 static pa_context *s_context = NULL;
 static enum { UNKNOWN, ACTIVE, INACTIVE } s_pulseActive = UNKNOWN;
 static int s_outstandingRequests = 0;
@@ -108,7 +108,7 @@ static void translateMasksAndMaps(devinfo& dev)
     }
     if (1 == dev.channel_map.channels && PA_CHANNEL_POSITION_MONO == dev.channel_map.map[0]) {
         // We just use the left channel to represent this.
-        dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MLEFT);
+        dev.chanMask |= Volume::MLEFT;
         dev.chanIDs[0] = Volume::LEFT;
     } else {
         for (uint8_t i = 0; i < dev.channel_map.channels; ++i) {
@@ -118,39 +118,39 @@ static void translateMasksAndMaps(devinfo& dev)
                     return;
 
                 case PA_CHANNEL_POSITION_FRONT_LEFT:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MLEFT);
+                    dev.chanMask |= Volume::MLEFT;
                     dev.chanIDs[i] = Volume::LEFT;
                     break;
                 case PA_CHANNEL_POSITION_FRONT_RIGHT:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MRIGHT);
+                    dev.chanMask |= Volume::MRIGHT;
                     dev.chanIDs[i] = Volume::RIGHT;
                     break;
                 case PA_CHANNEL_POSITION_FRONT_CENTER:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MCENTER);
+                    dev.chanMask |= Volume::MCENTER;
                     dev.chanIDs[i] = Volume::CENTER;
                     break;
                 case PA_CHANNEL_POSITION_REAR_CENTER:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MREARCENTER);
+                    dev.chanMask |= Volume::MREARCENTER;
                     dev.chanIDs[i] = Volume::REARCENTER;
                     break;
                 case PA_CHANNEL_POSITION_REAR_LEFT:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MSURROUNDLEFT);
+                    dev.chanMask |= Volume::MSURROUNDLEFT;
                     dev.chanIDs[i] = Volume::SURROUNDLEFT;
                     break;
                 case PA_CHANNEL_POSITION_REAR_RIGHT:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MSURROUNDRIGHT);
+                    dev.chanMask |= Volume::MSURROUNDRIGHT;
                     dev.chanIDs[i] = Volume::SURROUNDRIGHT;
                     break;
                 case PA_CHANNEL_POSITION_LFE:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MWOOFER);
+                    dev.chanMask |= Volume::MWOOFER;
                     dev.chanIDs[i] = Volume::WOOFER;
                     break;
                 case PA_CHANNEL_POSITION_SIDE_LEFT:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MREARSIDELEFT);
+                    dev.chanMask |= Volume::MREARSIDELEFT;
                     dev.chanIDs[i] = Volume::REARSIDELEFT;
                     break;
                 case PA_CHANNEL_POSITION_SIDE_RIGHT:
-                    dev.chanMask = (Volume::ChannelMask)( dev.chanMask | Volume::MREARSIDERIGHT);
+                    dev.chanMask |= Volume::MREARSIDERIGHT;
                     dev.chanIDs[i] = Volume::REARSIDERIGHT;
                     break;
                 default:
@@ -646,8 +646,8 @@ static void context_state_callback(pa_context *c, void *)
         if (s_context == c) {
             pa_context_set_subscribe_callback(c, subscribe_cb, NULL);
 
-            op = pa_context_subscribe(c, (pa_subscription_mask_t)
-                                           (PA_SUBSCRIPTION_MASK_SINK|
+            op = pa_context_subscribe(c, static_cast<pa_subscription_mask_t>(
+                                            PA_SUBSCRIPTION_MASK_SINK|
                                             PA_SUBSCRIPTION_MASK_SOURCE|
                                             PA_SUBSCRIPTION_MASK_CLIENT|
                                             PA_SUBSCRIPTION_MASK_SINK_INPUT|
@@ -689,8 +689,6 @@ static void context_state_callback(pa_context *c, void *)
         if (s_context != c) {
             pa_context_disconnect(c);
         } else {
-            // If we're not probing, it means we've been disconnected from our
-            // GLib context
             pa_context_unref(s_context);
             s_context = NULL;
 
@@ -717,7 +715,7 @@ static void setVolumeFromPulse(Volume& volume, const devinfo& dev)
     for (iter = dev.chanIDs.begin(); iter != dev.chanIDs.end(); ++iter)
     {
         //qCDebug(KMIX_LOG) <<  "Setting volume for channel " << iter.value() << " to " << (long)dev.volume.values[iter.key()] << " (" << ((100*(long)dev.volume.values[iter.key()]) / PA_VOLUME_NORM) << "%)";
-        volume.setVolume(iter.value(), (long)dev.volume.values[iter.key()]);
+        volume.setVolume(iter.value(), static_cast<long>(dev.volume.values[iter.key()]));
     }
 }
 
@@ -728,7 +726,7 @@ static pa_cvolume genVolumeForPulse(const devinfo& dev, Volume& volume)
     chanIDMap::const_iterator iter;
     for (iter = dev.chanIDs.begin(); iter != dev.chanIDs.end(); ++iter)
     {
-        cvol.values[iter.key()] = (uint32_t)volume.getVolume(iter.value());
+        cvol.values[iter.key()] = static_cast<uint32_t>(volume.getVolume(iter.value()));
         //qCDebug(KMIX_LOG) <<  "Setting volume for channel " << iter.value() << " to " << cvol.values[iter.key()] << " (" << ((100*cvol.values[iter.key()]) / PA_VOLUME_NORM) << "%)";
     }
     return cvol;
@@ -755,9 +753,8 @@ static devmap* get_widget_map(int type, QString id = QString())
 
 static devmap* get_widget_map(int type, int index)
 {
-    if (PA_INVALID_INDEX == (uint32_t)index)
-        return get_widget_map(type, "restore:");
-    return get_widget_map(type);
+    if (static_cast<uint32_t>(index)==PA_INVALID_INDEX) return (get_widget_map(type, "restore:"));
+    return (get_widget_map(type));
 }
 
 void Mixer_PULSE::emitControlsReconfigured()
@@ -956,10 +953,14 @@ bool Mixer_PULSE::connectToDaemon()
     Q_ASSERT(NULL == s_context);
 
     qCDebug(KMIX_LOG) <<  "Attempting connection to PulseAudio sound daemon";
-    pa_mainloop_api *api = pa_glib_mainloop_get_api(s_mainloop);
-    Q_ASSERT(api);
 
-    s_context = pa_context_new(api, "KMix");
+    // No need to create this until necessary
+    if (!m_mainloop) {
+        // When bumping c++ requirement to c++14,
+        // replace with `= std::make_unique<QtPaMainLoop>();`
+        m_mainloop.reset(new QtPaMainLoop);
+    }
+    s_context = pa_context_new(&m_mainloop->pa_vtable, "KMix");
     Q_ASSERT(s_context);
 
     if (pa_context_connect(s_context, NULL, PA_CONTEXT_NOFAIL, 0) < 0) {
@@ -981,13 +982,6 @@ Mixer_PULSE::Mixer_PULSE(Mixer *mixer, int devnum) : Mixer_Backend(mixer, devnum
     if (pulseenv.toInt())
         s_pulseActive = INACTIVE;
 
-    // We require a glib event loop
-    if (!QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("EventDispatcherGlib") &&
-        !QByteArray(QAbstractEventDispatcher::instance()->metaObject()->className()).contains("GlibEventDispatcher")) {
-        qCDebug(KMIX_LOG) << "Disabling PulseAudio integration for lack of GLib event loop";
-        s_pulseActive = INACTIVE;
-    }
-
     ++refcount;
     if (INACTIVE != s_pulseActive && 1 == refcount)
     {
@@ -1040,9 +1034,6 @@ Mixer_PULSE::Mixer_PULSE(Mixer *mixer, int devnum) : Mixer_Backend(mixer, devnum
         if (INACTIVE != s_pulseActive)
         {
             // Reconnect via integrated mainloop
-            s_mainloop = pa_glib_mainloop_new(NULL);
-            Q_ASSERT(s_mainloop);
-
             connectToDaemon();
 
 #if defined(HAVE_CANBERRA)
@@ -1082,11 +1073,6 @@ Mixer_PULSE::~Mixer_PULSE()
                 pa_context_unref(s_context);
                 s_context = NULL;
             }
-
-            if (s_mainloop) {
-                pa_glib_mainloop_free(s_mainloop);
-                s_mainloop = NULL;
-            }
         }
     }
 
@@ -1217,9 +1203,8 @@ case KMIXPA_PLAYBACK:
 
                                     if (playing==0)
                                     {
-                                        char devnum[64];
-                                        snprintf(devnum, sizeof(devnum), "%lu", (unsigned long) dev.index);
-                                        ca_context_change_device(s_ccontext, devnum);
+                                        const QByteArray devnum = QByteArray::number(dev.index);
+                                        ca_context_change_device(s_ccontext, devnum.constData());
 
                                         // Ideally we'd use something like ca_gtk_play_for_widget()...
                                         ca_context_play(
